@@ -70,7 +70,7 @@ def visualize_tsne_phenotypes(dataset, IndexAndClass,clusters):
         for ph in range(pheno_assignmnents.shape[1]):
 
             # Create and save scatter plot figure
-            plt.close()
+            plt.close('all')
             fig, ax = plt.subplots()   
             scatter = ax.scatter(embedding[:, 0],embedding[:, 1],s=0.5,c=pheno_assignmnents[:,ph],vmin=0,vmax=1,cmap='jet',edgecolors='none')        
             plt.title('TSNE of the dataset Phenoptype - '+str(ph+1), fontsize=24)    
@@ -81,7 +81,7 @@ def visualize_tsne_phenotypes(dataset, IndexAndClass,clusters):
         for ph in range(pheno_assignmnents.shape[1]):
             thr = np.percentile(pheno_assignmnents[pheno_assignmnents.argmax(1)==ph,ph],75)
             pheno_assignmnents_75[np.logical_and(pheno_assignmnents.argmax(1)==ph,pheno_assignmnents[:,ph]>=thr)] = ph+1
-        plt.close()
+        plt.close('all')
         fig, ax = plt.subplots()   
         scatter = ax.scatter(embedding[:, 0],embedding[:, 1],s=0.5,c=pheno_assignmnents_75,cmap='jet',edgecolors='none')        
         plt.title('TSNE of the dataset ALL_Phenotypes Q4', fontsize=24)    
@@ -305,12 +305,16 @@ def save_2Dmatrix_in_excel_with_names(filename,matrix,Names):
     dict_ = pd.DataFrame.from_dict(dict_)      
     dict_.to_excel(filename) 
 
-def save_heatmap_with_names(filename,matrix,Names):    
+def save_heatmap_with_names(filename,matrix,Names):   
+    import sys
+    sys.setrecursionlimit(1000000) 
     if matrix.shape[0]>2:
-        plt.close()
+        plt.close('all')
         plt.figure()
         sns.set(font_scale=1.1)
-        h_E_Fig = sns.clustermap(matrix, col_cluster=True, row_cluster=True, xticklabels=Names, linewidths=0,vmin=-2, vmax=2, cmap="bwr")                
+        scaler = StandardScaler()
+        scaler.fit(matrix)        
+        h_E_Fig = sns.clustermap(scaler.transform(matrix)*25+128, row_cluster=True, xticklabels=Names, linewidths=0,vmin=-2, vmax=2, cmap="bwr")                
         h_E_Fig.savefig(filename,dpi=600) 
 
 def calculate_pearson_correlation(matrix_0,matrix_1):
@@ -371,7 +375,7 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
         mult_2 = 4
 
     ## Iterate through Phenotypes to extract topk patches
-    k=81
+    k=100
     topkPatches=[]
     # Create a heatmap marker using topk patches
     heatmapMarkerExpression = np.zeros((7,len(CropConf),len(Marker_Names))) #Number of TMEs x number of markers
@@ -387,15 +391,22 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
         # Choose patches with most confidence
         topkPheno = np.array([CCP[1] for CCP in CropConf_i]).argsort()[-k:]        
         # Save topkPheno to heatMarkerMap. Mean
-        MarkerExpression = np.array([CropConf_i[t][0] for t in topkPheno])
+        MarkerExpression = np.array([CropConf_i[t][0].mean((0,1)) for t in topkPheno])
+        
+        # heatmap_Colocalization[n_cell_type,:] = calculate_marker_colocalization(MarkerExpression,Marker_Names)
+        # try:
+        #     heatmap_CellSize_circularity[n_cell_type,:] = calculate_Cell_Size_circularity(thisfolder,MarkerExpression[:,:,:,Marker_Names.index('DAPI')])
+        # except:
+        #     print('could not calculate cell size circularity because DAPI marker is missing')
+        
+        # # Save marker expression of patches individually
+        # if cell_type=='Phenotypes':        
+        #     save_heatmap_with_names(thisfolder+'TME_{}_patchExpression.png'.format(n_cell_type+1),MarkerExpression.mean((1,2)),Marker_Names)            
+        # else:
+        #     expr = MarkerExpression[:,::int(dataset.patch_size/10),::int(dataset.patch_size/10),:]            
+        #     save_heatmap_with_names(thisfolder+'TME_{}_patchExpression.png'.format(n_cell_type+1),np.array([expr[:,:,:,i].flatten() for i in range(expr.shape[3])]).T,Marker_Names)
 
-        heatmap_Colocalization[n_cell_type,:] = calculate_marker_colocalization(MarkerExpression,Marker_Names)
-        try:
-            heatmap_CellSize_circularity[n_cell_type,:] = calculate_Cell_Size_circularity(thisfolder,MarkerExpression[:,:,:,Marker_Names.index('DAPI')])
-        except:
-            print('could not calculate cell size circularity because DAPI marker is missing')
-
-        MarkerExpression = np.reshape(MarkerExpression,(MarkerExpression.shape[0]*MarkerExpression.shape[1]*MarkerExpression.shape[2],MarkerExpression.shape[3]))
+        # MarkerExpression = np.reshape(MarkerExpression,(MarkerExpression.shape[0]*MarkerExpression.shape[1]*MarkerExpression.shape[2],MarkerExpression.shape[3]))
         heatmapMarkerExpression[0,n_cell_type,:] = np.mean(MarkerExpression,axis=0)                    
         for n_i, i in enumerate(Thresholds[1:]):
             heatmapMarkerExpression[n_i+1,n_cell_type,:] = np.percentile(MarkerExpression,i,axis=0)                    
@@ -418,15 +429,15 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
                 ImwithKPatches[int(row*mult_1*dataset.patch_size+row*mult_2):int((row+1)*mult_1*dataset.patch_size+row*mult_2),int(col*mult_1*dataset.patch_size+col*mult_2):int((col+1)*mult_1*dataset.patch_size+col*mult_2),:] = 0.0
                             
             # RGBImwithKPatches = dataset.nPlex2RGB(ImwithKPatches)
-            imwrite(thisfolder+'Cell_type_{}_Raw.tiff'.format(n_cell_type+1),np.moveaxis(ImwithKPatches,2,0))
+            imwrite(thisfolder+'Cell_type_{}_Raw.tiff'.format(n_cell_type+1),np.moveaxis(ImwithKPatches,2,0), photometric='minisblack')
             
             # Save Certainty of this Phenotype
-            plt.close()
+            plt.close('all')
             plt.figure()
             n, bins, patches = plt.hist(np.array([i[1] for i in CropConf_i]), 100, color=cm.jet_r(int(n_cell_type*(255/int(len(CropConf))))), alpha=1)            
-            plt.ylabel('Number of Superpatches',fontsize=16)            
-            plt.xlabel('Level of cell type certainty',fontsize=16)
-            plt.title('Histogram of phenotype '+str(n_cell_type+1)+' Certainty',fontsize=16)
+            plt.ylabel('Number of Patches',fontsize=16)            
+            plt.xlabel('Level of TME certainty',fontsize=16)
+            plt.title('Histogram of TME ' + str(n_cell_type+1) + ' certainty',fontsize=16)
             plt.savefig(thisfolder+'ConfidenceHistogram_{}.png'.format(n_cell_type+1), format="PNG",dpi=600)                                         
 
         # Assign topkPheno Patches
@@ -438,7 +449,7 @@ def save_heatmap_raw_and_normalized(filename, heatmap, TME_names,Colormap,Marker
     y_ticklabels = TME_names[heatmap.sum(1)!=0]
     c_map = Colormap[:heatmap.shape[0]][heatmap.sum(1)!=0]
     # Figure Heatmap Raw Values
-    plt.close()
+    plt.close('all')
     plt.figure()
     sns.set(font_scale=1.1)
     cluster=True if (heatmap.sum(1)!=0).sum()>1 else False
@@ -449,7 +460,7 @@ def save_heatmap_raw_and_normalized(filename, heatmap, TME_names,Colormap,Marker
     h_E_COL_MinMax = heatmap[heatmap.sum(1)!=0,:] - heatmap[heatmap.sum(1)!=0,:].min(0,keepdims=True)
     h_E_COL_MinMax = h_E_COL_MinMax/h_E_COL_MinMax.max(0,keepdims=True)
     h_E_COL_MinMax[np.isnan(h_E_COL_MinMax)] = 0 
-    plt.close()
+    plt.close('all')
     plt.figure()
     sns.set(font_scale=1.1)
     if (h_E_COL_MinMax.sum(1)!=0).sum()==1: # One column heatmap
@@ -464,7 +475,7 @@ def save_heatmap_raw_and_normalized(filename, heatmap, TME_names,Colormap,Marker
     # Figure Heatmap z-scored values
     h_E_COL_Norm = stats.zscore(heatmap[heatmap.sum(1)!=0,:],axis=0)  
     h_E_COL_Norm[np.isnan(h_E_COL_Norm)] = 0              
-    plt.close()
+    plt.close('all')
     plt.figure()
     sns.set(font_scale=1.1)    
     if (h_E_COL_Norm.sum(1)!=0).sum()==1: # One column heatmap
@@ -474,6 +485,19 @@ def save_heatmap_raw_and_normalized(filename, heatmap, TME_names,Colormap,Marker
         h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=True, vmin=-2, vmax=2, row_cluster=True, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
         h_E_Fig.savefig(filename+'_Norm.png',dpi=600) 
 
+    # Figure Heatmap z-scored values
+    h_E_COL_Norm = stats.zscore(h_E_COL_Norm[heatmap.sum(1)!=0,:],axis=1)  
+    h_E_COL_Norm[np.isnan(h_E_COL_Norm)] = 0              
+    plt.close('all')
+    plt.figure()
+    sns.set(font_scale=1.1)    
+    if (h_E_COL_Norm.sum(1)!=0).sum()==1: # One column heatmap
+        h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=False, vmin=-2, vmax=2, row_cluster=False, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
+        h_E_Fig.savefig(filename+'_Norm_rows.png',dpi=600) 
+    elif (h_E_COL_Norm.sum(1)!=0).sum()>1: # Normal heatmap
+        h_E_Fig = sns.clustermap(h_E_COL_Norm,col_cluster=True, vmin=-2, vmax=2, row_cluster=True, row_colors=c_map,xticklabels=Marker_Names,yticklabels=y_ticklabels, linewidths=0.5, cmap="bwr")            
+        h_E_Fig.savefig(filename+'_Norm_rows.png',dpi=600) 
+
 def save_heatMapMarker_and_barplot(dataset, heatmapMarkerExpression, heatmapMarkerColocalization, heatmap_CellSize_circularity, CropConf,Marker_Names,cell_type,Thresholds):
     '''
     '''
@@ -489,19 +513,19 @@ def save_heatMapMarker_and_barplot(dataset, heatmapMarkerExpression, heatmapMark
         save_heatmap_raw_and_normalized(dataset.bioInsights_dir_cell_types+cell_type+'/heatmap_MarkerExpression_'+str(j), 
                                         heatmapMarkerExpression[n_j,:,:], np.array([abrev+str(i+1) for i in range(len(CropConf))]),
                                         Colormap,Marker_Names)
-        save_heatmap_raw_and_normalized(dataset.bioInsights_dir_cell_types+cell_type+'/heatmap_MarkerExpression_Colocalization_'+str(j), 
-                                        np.concatenate((heatmapMarkerExpression[n_j,:,:],heatmapMarkerColocalization),axis=1), np.array([abrev+str(i+1) for i in range(len(CropConf))]),
-                                        Colormap,Marker_Names+['_'.join(i) for i in itertools.combinations(Marker_Names,2)])
+        # save_heatmap_raw_and_normalized(dataset.bioInsights_dir_cell_types+cell_type+'/heatmap_MarkerExpression_Colocalization_'+str(j), 
+        #                                 np.concatenate((heatmapMarkerExpression[n_j,:,:],heatmapMarkerColocalization),axis=1), np.array([abrev+str(i+1) for i in range(len(CropConf))]),
+        #                                 Colormap,Marker_Names+['_'.join(i) for i in itertools.combinations(Marker_Names,2)])
         
 
-    try:
-        save_heatmap_raw_and_normalized(dataset.bioInsights_dir_cell_types + cell_type + '/heatmap_Size_Circularity', heatmap_CellSize_circularity, np.array([abrev+str(i+1) for i in range(len(CropConf))]),Colormap,['Nucleus Size', 'Nucleus circularity'])
-    except:
-        print('')
-    save_heatmap_raw_and_normalized(dataset.bioInsights_dir_cell_types + cell_type + '/heatmap_Colocalization', heatmapMarkerColocalization, np.array([abrev+str(i+1) for i in range(len(CropConf))]),Colormap,['_'.join(i) for i in itertools.combinations(Marker_Names,2)])
+    # try:
+    #     save_heatmap_raw_and_normalized(dataset.bioInsights_dir_cell_types + cell_type + '/heatmap_Size_Circularity', heatmap_CellSize_circularity, np.array([abrev+str(i+1) for i in range(len(CropConf))]),Colormap,['Nucleus Size', 'Nucleus circularity'])
+    # except:
+    #     print('')
+    # save_heatmap_raw_and_normalized(dataset.bioInsights_dir_cell_types + cell_type + '/heatmap_Colocalization', heatmapMarkerColocalization, np.array([abrev+str(i+1) for i in range(len(CropConf))]),Colormap,['_'.join(i) for i in itertools.combinations(Marker_Names,2)])
 
     # Calculate Phenotype abundance across all patients
-    plt.close()
+    plt.close('all')
     plt.figure()
     sns.set(font_scale=1.0)
     BarPlotPresenceOfPhenotypes = sns.barplot(x=[abrev+str(i+1) for i in range(len(CropConf))] ,y=np.array([len(i) for i in CropConf]),palette=Colormap)      
@@ -542,12 +566,12 @@ def obtain_neighborhood_composition(dataset,CropConfPheno,CropConfTissueComm):
 
     # Save interactivity matrix
     sns.set(font_scale=1.5)
-    plt.close()
+    plt.close('all')
     heatmapInteractivityMatrix_Fig = sns.clustermap(InteractivityMatrix,col_cluster=False, row_cluster=False, row_colors=Colormap_Neigh, col_colors=Colormap_Pheno,xticklabels=['P'+str(i+1) for i in range(len(CropConfPheno))],yticklabels=['N'+str(i+1) for i in range(len(CropConfTissueComm))], linewidths=0.5, cmap="bwr")            
     plt.xlabel("Phenotypes")
     plt.ylabel("Neighborhoods")
     heatmapInteractivityMatrix_Fig.savefig(dataset.bioInsights_dir_cell_types+'Neighborhoods/heatmap_InteractivityMat_Raw.png',dpi=600) 
-    plt.close()
+    plt.close('all')
     InteractivityMatrix[InteractivityMatrix==0]=1e-3
     heatmapInteractivityMatrix_Fig = sns.clustermap(stats.zscore(InteractivityMatrix,axis=1),col_cluster=False, row_cluster=False, row_colors=Colormap_Neigh, col_colors=Colormap_Pheno,xticklabels=['P'+str(i+1) for i in range(len(CropConfPheno))],yticklabels=['N'+str(i+1) for i in range(len(CropConfTissueComm))], linewidths=0.5, cmap="bwr")            
     plt.xlabel("Phenotypes")
@@ -556,54 +580,62 @@ def obtain_neighborhood_composition(dataset,CropConfPheno,CropConfTissueComm):
 
 def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, ClusteringThreshold):
     
-    # Initialize variables for neighborhood and areas            
-    Area_to_Neigh = np.zeros((clusters[-1],clusters[-2]))                
-    Neigh_to_Pheno = np.zeros((clusters[-2],clusters[-3]))            
+    # Initialize variables
+    neigh_to_area = []
+    patch_to_pheno = []
+    patch_to_neigh = []
 
     # Obtain clusters per Slide
     for count, idxclster in enumerate(IndexAndClass):           
         try:
+
+            # Load assignment
             neigh_to_area_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignment_Index_{}_ClustLvl_{}.npy'.format(idxclster[1], clusters[-1])))                
             patch_to_neigh_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignmentPerPatch_Index_{}_0_ClustLvl_{}.npy'.format(idxclster[1], clusters[-2])))        
-            patch_to_pheno_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignmentPerPatch_Index_{}_0_ClustLvl_{}.npy'.format(idxclster[1], clusters[-3])))         
+            patch_to_pheno_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignmentPerPatch_Index_{}_0_ClustLvl_{}.npy'.format(idxclster[1], clusters[-3])))                             
             data = dataset.get(idxclster[1],0)
-            patch_to_neigh_assignment[data.num_nodes:,:] = 0
-            patch_to_pheno_assignment[data.num_nodes:,:] = 0
+
+            # Save assignments
+            neigh_to_area.append(neigh_to_area_assignment)
+            patch_to_neigh.append(patch_to_neigh_assignment[:data.num_nodes,:])            
+            patch_to_pheno.append(patch_to_pheno_assignment[:data.num_nodes,:])                        
         except:
             continue
 
-        # Normalize each pheno, neigh, area
-        neigh_to_area_assignment = neigh_to_area_assignment-neigh_to_area_assignment.min(0,keepdims=True)
-        neigh_to_area_assignment = neigh_to_area_assignment/neigh_to_area_assignment.max(0,keepdims=True)
-        patch_to_neigh_assignment = patch_to_neigh_assignment-patch_to_neigh_assignment.min(0,keepdims=True)
-        patch_to_neigh_assignment = patch_to_neigh_assignment/patch_to_neigh_assignment.max(0,keepdims=True)
-        patch_to_pheno_assignment = patch_to_pheno_assignment-patch_to_pheno_assignment.min(0,keepdims=True)
-        patch_to_pheno_assignment = patch_to_pheno_assignment/patch_to_pheno_assignment.max(0,keepdims=True)
+    # Calculate Neighborhoods to areas
+    neigh_to_area = np.stack(neigh_to_area) # pat x neigh x areas
+    PercTHrsl_area = np.percentile(neigh_to_area,axis=(0,1),q=ClusteringThreshold)
+    Area_to_Neigh = np.zeros((clusters[-1],clusters[-2])) 
+    for area in range(clusters[-1]):
+        Area_to_Neigh[area,:] = np.sum(neigh_to_area[:,:,area]*np.array(neigh_to_area[:,:,area]>PercTHrsl_area[area]),0)
 
-        # Assign area to neighborhood
-        Area_to_Neigh += np.transpose(neigh_to_area_assignment)
-        
-        # Calculate percentile        
-        PercTHrsl_area = np.percentile(neigh_to_area_assignment[:data.num_nodes,:],axis=0,q=ClusteringThreshold)
-        PercTHrsl_neigh = np.percentile(patch_to_neigh_assignment[:data.num_nodes,:],axis=0,q=ClusteringThreshold)
-        PercTHrsl_pheno = np.percentile(patch_to_pheno_assignment[:data.num_nodes,:],axis=0,q=ClusteringThreshold)
-        
-        # Assign neighborhood
-        for i in range(neigh_to_area_assignment.shape[1]):
-            neigh_to_area_assignment[:,i][PercTHrsl_area[i]>=neigh_to_area_assignment[:,i]] = 0             
+    # Save Neighborhoods to areas heatmap
+    plt.close('all')
+    plt.figure()
+    sns.set(font_scale=1.1)
+    row_colors_Area=cm.jet_r(range(0,255,int(255/clusters[2])))[:,:3]
+    yticklabels_Area = ['A'+str(i+1) for i in range(clusters[2])]
+    col_colors_Neigh=cm.jet_r(range(0,255,int(255/clusters[1])))[:,:3]
+    xticklabels_Neigh = ['N'+str(i+1) for i in range(clusters[1])]
+    Area_to_Neigh = Area_to_Neigh/Area_to_Neigh.sum(1,keepdims=True)*100    
+    Area_to_Neigh[np.isnan(Area_to_Neigh)] = 0
+    h_E_Fig = sns.clustermap(Area_to_Neigh.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Area,
+                                row_colors=col_colors_Neigh,yticklabels=xticklabels_Neigh,xticklabels=yticklabels_Area, linewidths=0.5, cmap="bwr")            
+    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'heatmap_Neighborhood_composition_of_Areas_Perc_'+str(ClusteringThreshold)+'.png',dpi=600) 
 
-        # Assign neighborhood
-        for i in range(patch_to_neigh_assignment.shape[1]):
-            patch_to_neigh_assignment[:,i][PercTHrsl_neigh[i]>=patch_to_neigh_assignment[:,i]] = 0 
-        
-        # Assign Phenotype
-        for i in range(patch_to_pheno_assignment.shape[1]):
-            patch_to_pheno_assignment[:,i][PercTHrsl_pheno[i]>=patch_to_pheno_assignment[:,i]] = 0                 
+    # Phenotypes to neighborhoods
+    patch_to_neigh = np.concatenate(patch_to_neigh,0) # patches x neigh
+    patch_to_pheno = np.concatenate(patch_to_pheno,0) # patches x pheno    
+    PercTHrsl_neigh = np.percentile(patch_to_neigh_assignment,axis=0,q=ClusteringThreshold)
+    PercTHrsl_pheno = np.percentile(patch_to_pheno,axis=0,q=ClusteringThreshold)        
+    for i in range(patch_to_neigh.shape[1]):
+        patch_to_neigh[:,i][PercTHrsl_neigh[i]>=patch_to_neigh[:,i]] = 0 
+    for i in range(patch_to_pheno.shape[1]):
+        patch_to_pheno[:,i][PercTHrsl_pheno[i]>=patch_to_pheno[:,i]] = 0        
+    Neigh_to_Pheno = np.matmul(np.transpose(patch_to_neigh),patch_to_pheno)
 
-        Neigh_to_Pheno += np.matmul(np.transpose(patch_to_neigh_assignment[:data.num_nodes,:]),patch_to_pheno_assignment[:data.num_nodes,:])
-
-    # Save heatmap Neigh_to_Pheno Normalized
-    plt.close()
+    # Save heatmap Neigh_to_Pheno
+    plt.close('all')
     plt.figure()
     sns.set(font_scale=1.1)
     row_colors_Neigh=cm.jet_r(range(0,255,int(255/clusters[1])))[:,:3]
@@ -616,16 +648,4 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
                                 row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, linewidths=0.5, cmap="bwr")            
     h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Perc_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
 
-    # Save heatmap Neigh_to_Pheno Normalized
-    plt.close()
-    plt.figure()
-    sns.set(font_scale=1.1)
-    row_colors_Area=cm.jet_r(range(0,255,int(255/clusters[2])))[:,:3]
-    yticklabels_Area = ['A'+str(i+1) for i in range(clusters[2])]
-    col_colors_Neigh=cm.jet_r(range(0,255,int(255/clusters[1])))[:,:3]
-    xticklabels_Neigh = ['N'+str(i+1) for i in range(clusters[1])]
-    Area_to_Neigh = Area_to_Neigh/Area_to_Neigh.sum(1,keepdims=True)*100    
-    Area_to_Neigh[np.isnan(Area_to_Neigh)] = 0
-    h_E_Fig = sns.clustermap(Area_to_Neigh.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Area,
-                                row_colors=col_colors_Neigh,yticklabels=xticklabels_Neigh,xticklabels=yticklabels_Area, linewidths=0.5, cmap="bwr")            
-    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'heatmap_Neighborhood_composition_of_Areas_Perc.png',dpi=600) 
+    
