@@ -462,7 +462,7 @@ class NaroNet_dataset(torch.utils.data.Dataset):
                         edge_index = torch.unique_consecutive(edge_index,dim=1)
 
                         #  Mean node degree
-                        print('Mean Node Degree:'+str(edge_index.shape[1]/sum(Truexy==True))+' '+files[file_index])
+                        # print('Mean Node Degree:'+str(edge_index.shape[1]/sum(Truexy==True))+' '+files[file_index])
                                                     
                         # Assign node attributes and label.
                         x = torch.from_numpy(file[np.squeeze(Truexy),:][:,2:])                                                
