@@ -97,7 +97,7 @@ def calc_contrast_loss(features,assignment_orig,device,args):
 
 
     # Number of patches going to 
-    pos_batch = max(min(int(assignment_orig.shape[0]*args['Perc_high_conf_patches']),assignment_orig.shape[0]),4,assignment_orig.shape[1])
+    pos_batch = max(int(assignment_orig.shape[0]*args['Perc_high_conf_patches']),1)
 
     # Calculate feature similarities
     features = F.normalize(features.squeeze(), dim=1)    
@@ -122,7 +122,8 @@ def calc_contrast_loss(features,assignment_orig,device,args):
         
         # Positive loss - patches with similar features to the top-k patches should have the same assignment
         positives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][top_elem].T)/temp)) 
-        loss += -torch.log(positives).mean()*temp       
+
+        # loss += -torch.log(positives).mean()*temp       
         
 
         # combine feature dist and assignment
@@ -132,10 +133,11 @@ def calc_contrast_loss(features,assignment_orig,device,args):
         
 
         # Patches with highest confidence assignment          
-        # bottom_val = feat_dist.topk(pos_batch*9,0,largest=False)[1]
-        # # Negative loss - patches with dissimilar features to the top-k patches but with high assignment confidence should have a dissimilar assignment.
-        # negatives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][bottom_val].T)/temp))        
-        # loss += torch.log(negatives).mean()*temp
+        bottom_val = feat_dist.topk(pos_batch*9,0,largest=False)[1]
+        sel_vals_neg = torch.randint(0, pos_batch*9, (pos_batch,))
+        # Negative loss - patches with dissimilar features to the top-k patches but with high assignment confidence should have a dissimilar assignment.
+        negatives = torch.exp((torch.matmul(objective,assignment_orig[top_assignment][bottom_val[sel_vals_neg]].T)/temp))        
+        loss += -torch.log(positives/negatives).mean()
         # print('Positives: '+str((torch.log(positives).mean()*temp).item()*100)[:5]+' feat_pos: '+str(feat_dist[top_elem[0]].item())[:6]+'   -   Negative: '+str((torch.log(negatives).mean()*temp).item()*100)[:5]+' feat_neg: '+str(feat_dist[bottom_val[0]].item())[:6])
         
     return loss/assignment_orig.shape[1]
