@@ -33,7 +33,7 @@ def parameters(path, debug):
         args['PCL_Color_perturbation_Augmentation'] = False # Whether to use color normalization augmentation in H&E white-field microscopy images. Used to force PCL to learn morphological features and avoid learning color staining features. 
 
         # Label you want to infer with respect the images.
-        args['experiment_Label'] = ['Mutation'] 
+        args['experiment_Label'] = ['Unsupervised'] 
 
         # Architecture Search parameters
         args['num_samples_architecture_search'] = 800  
@@ -44,7 +44,7 @@ def parameters(path, debug):
         args['lr_decay_factor'] = 0.25# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 11000#max(int(args['epochs']/2),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
-        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 12, 25]) if debug=='Object' else 12
+        args['batch_size'] = 2 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 12, 25]) if debug=='Object' else 8
         args['lr'] = 2 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.01
 
         # General
@@ -56,8 +56,9 @@ def parameters(path, debug):
             
         # Neural Network
         args['N_Phenotypes'] = 0 if debug=='Index' else hp.choice('clusters1',[8,10,15,20]) if debug=='Object' else 8   
-        args['N_Neighborhoods'] = 1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 16
+        args['N_Neighborhoods'] = 2 if debug=='Index' else hp.choice('clusters2',[6,11,12,21]) if debug=='Object' else 12
         args['N_Areas'] = 1 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 4      
+        args['n_hops_neighborhoods'] = 1
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True
         args['Area_Learning'] = True
@@ -75,6 +76,7 @@ def parameters(path, debug):
 
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = False
+        args['Perc_high_conf_patches'] = 0.0001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. A low values generates rare populations.                                  
         args['TSNE_Perc_Pat'] = 0 # Percentage of patients to use to generate the tsne.     
 
 
@@ -304,7 +306,7 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 100# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['epochs'] = 1000# if debug else hp.quniform('epochs', 5, 25, 1)
         args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
@@ -373,24 +375,24 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 100# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['epochs'] = 20# if debug else hp.quniform('epochs', 5, 25, 1)
         args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
-        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 64]) if debug=='Object' else 64
-        args['lr'] = 3 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.001
+        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 32]) if debug=='Object' else 32
+        args['lr'] = 1 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.1
 
         # General
         args['training_MODE'] = 'CrossValidation' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
-        args['folds'] = 24
+        args['folds'] = 12
         args['device'] = 'cuda:0'
         args['Batch_Normalization'] = True
         args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
 
         # Neural Network
-        args['N_Phenotypes'] = 4#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
-        args['N_Neighborhoods'] = 6#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
-        args['N_Areas'] = 2#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
+        args['N_Phenotypes'] = 6#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
+        args['N_Neighborhoods'] = 8#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
+        args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
         args['n_hops_neighborhoods'] = 3
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True
@@ -404,9 +406,9 @@ def parameters(path, debug):
         args['ContrastACC_Neigh'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
         args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001 
         args['Perc_high_conf_patches'] = 0.001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. Low values generate rare populations.
-        args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
-        args['PatchEntropy_Neigh'] = 0#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
-        args['PatchEntropy_Area'] = 0#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
+        args['PatchEntropy_Pheno'] = 0.001#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
+        args['PatchEntropy_Neigh'] = 0.001#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
+        args['PatchEntropy_Area'] = 0.001#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
         
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = True
